## 5.7.0.0 (2023-01-07)

[stubsabot] Bump ujson to 5.7.* (#9473)

Release: https://pypi.org/pypi/ujson/5.7.0
Homepage: https://github.com/ultrajson/ultrajson
Diff: https://github.com/ultrajson/ultrajson/compare/5.6.0...5.7.0

Stubsabot analysis of the diff between the two releases:
 - Total lines of Python code added: 38.
 - Total lines of Python code deleted: 0.

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 5.6.0.0 (2022-12-02)

[stubsabot] Bump ujson to 5.6.* (#9319)

Release: https://pypi.org/pypi/ujson/5.6.0
Homepage: https://github.com/ultrajson/ultrajson
Diff: https://github.com/ultrajson/ultrajson/compare/5.5.0...5.6.0

Stubsabot analysis of the diff between the two releases:
 - Total lines of Python code added: 13.
 - Total lines of Python code deleted: 0.

## 5.5.0 (2022-09-16)

[stubsabot] Bump ujson to 5.5.* (#8749)

Release: https://pypi.org/project/ujson/5.5.0/
Homepage: https://github.com/ultrajson/ultrajson
Diff: https://github.com/ultrajson/ultrajson/compare/5.4.0...5.5.0

## 5.4.0 (2022-07-08)

[stubsabot] Bump ujson to 5.4.* (#8259)

Co-authored-by: hauntsaninja <>

## 5.3.1 (2022-06-25)

ujson, pyfarmhash, toposort: check for missing definitions (#8153)

Co-authored-by: hauntsaninja <>

## 5.3.0 (2022-06-14)

[stubsabot] Bump ujson to 5.3.* (#8078)

Co-authored-by: hauntsaninja <>

## 5.2.0 (2022-05-30)

ujson: add JSONDecodeError (#7988)

## 4.2.0 (2021-10-12)

Update remaining versions for third-party stubs (#6094)

Also remove the python2 markers of packages that don't list Python 2
as supported in the latest version.

Don't special case version '0.1'

Co-authored-by: Akuli <akuviljanen17@gmail.com>

